import {useMemo} from 'react'
import {useTable, ColumnInstance, Row} from 'react-table'
import { CustomHeaderColumn } from './CustomHeaderColumn'
import { CustomRow } from './CustomRow'
import {useQueryResponseData, useQueryResponseLoading} from '../../../core/QueryResponseProviderPosition'
import {positionsColumns} from '../../_columns'
import {Position} from '../../../core/_models'
import {ListLoading} from '../../../components/loading/ListLoading'
import {ListPagination} from '../../../components/pagination/ListPaginationPosition'
import {KTCardBody} from '../../../../../../../../_metronic/helpers'

const PositionsTable = () => {
  const positions = useQueryResponseData()
  const isLoading = useQueryResponseLoading()
  const data = useMemo(() => positions, [positions])
  const columns = useMemo(() => positionsColumns, [])
  const {getTableProps, getTableBodyProps, headers, rows, prepareRow} = useTable({
    columns,
    data,
  })
  
  return (
    <KTCardBody className='py-4'>
      
      <div className='table-responsive'>
        <table
          id='kt_table_positions'
          className='table align-middle table-row-dashed fs-6 gy-5 dataTable no-footer'
          {...getTableProps()}
        >
          <thead>
            <tr className='text-start text-muted fw-bolder fs-7 text-uppercase gs-0'>
              {headers.map((column: ColumnInstance<Position>) => (
                <CustomHeaderColumn key={column.id} column={column} />
              ))}
            </tr>
          </thead>
          <tbody className='text-gray-600 fw-bold' {...getTableBodyProps()}>
            {rows.length > 0 ? (
              rows.map((row: Row<Position>, i) => {
                prepareRow(row)
                return <CustomRow row={row} key={`row-${i}-${row.id}`} />
              })
            ) : (
              <tr>
                <td colSpan={7}>
                  <div className='d-flex text-center w-100 align-content-center justify-content-center'>
                    No matching records found
                  </div>
                </td>
              </tr>
            )}
          </tbody>
        </table>
      </div>
      <ListPagination />
      {isLoading && <ListLoading />}
      </KTCardBody>
      
  )
}

export {PositionsTable}
